<?php
/*
	* functions.php
*/

/**
 * Flush rewrite rules for custom post type archive on single activation
 *
 * @since    0.0.1
 */
add_action( 'plugins_loaded', 'pm_social_quiz_load_textdomain' );
function pm_social_quiz_load_textdomain() {
    load_plugin_textdomain( 'pm-social-quiz', false, dirname( plugin_basename( __DIR__ ) ) . '/languages' );
}

function pm_social_quiz_install() {
	pm_social_post_type_init();
	flush_rewrite_rules();
}

function pm_social_quiz_deactivate() {

}

add_action( 'init', 'pm_social_post_type_init' );
/**
 * Register a Social Quiz post type.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_post_type
 */
function pm_social_post_type_init() {
	$labels_social_quiz = array(
		'name'               => _x( 'Social Quizzes', 'post type general name', 'pm-social-quiz' ),
		'singular_name'      => _x( 'Social Quiz', 'post type singular name', 'pm-social-quiz' ),
		'menu_name'          => _x( 'Social Quizzes', 'admin menu', 'pm-social-quiz' ),
		'name_admin_bar'     => _x( 'Social Quiz', 'add new on admin bar', 'pm-social-quiz' ),
		'add_new'            => _x( 'Add New', 'Social Quiz', 'pm-social-quiz' ),
		'add_new_item'       => __( 'Add New Social Quiz', 'pm-social-quiz' ),
		'new_item'           => __( 'New Social Quiz', 'pm-social-quiz' ),
		'edit_item'          => __( 'Edit Social Quiz', 'pm-social-quiz' ),
		'view_item'          => __( 'View Social Quiz', 'pm-social-quiz' ),
		'all_items'          => __( 'All Social Quizzes', 'pm-social-quiz' ),
		'search_items'       => __( 'Search Social Quizzes', 'pm-social-quiz' ),
		'parent_item_colon'  => __( 'Parent Social Quizzes:', 'pm-social-quiz' ),
		'not_found'          => __( 'No Social Quizzes found.', 'pm-social-quiz' ),
		'not_found_in_trash' => __( 'No Social Quizzes found in Trash.', 'pm-social-quiz' )
	);

	$args_social_quiz = array(
		'labels'             => $labels_social_quiz,
		'public'             => true,
		'publicly_queryable' => true,
		'exclude_from_search' => true,
		'show_ui'            => true,
		'show_in_menu'       => true,
		'query_var'          => false,

		'capability_type'    => 'post',
		'has_archive'        => false,
		'hierarchical'       => false,
		'menu_position'      => null,
		'supports'           => array( 'title', 'editor', 'author', 'thumbnail')
	);
	
	$labels_social_question = array(
		'name'               => _x( 'Questions', 'post type general name', 'pm-social-quiz' ),
		'singular_name'      => _x( 'Question', 'post type singular name', 'pm-social-quiz' ),
		'menu_name'          => _x( 'Questions', 'admin menu', 'pm-social-quiz' ),
		'name_admin_bar'     => _x( 'Question', 'add new on admin bar', 'pm-social-quiz' ),
		'add_new'            => _x( 'Add New', 'Question', 'pm-social-quiz' ),
		'add_new_item'       => __( 'Add New Question', 'pm-social-quiz' ),
		'new_item'           => __( 'New Question', 'pm-social-quiz' ),
		'edit_item'          => __( 'Edit Question', 'pm-social-quiz' ),
		'view_item'          => __( 'View Question', 'pm-social-quiz' ),
		'all_items'          => __( 'All Questions', 'pm-social-quiz' ),
		'search_items'       => __( 'Search Questions', 'pm-social-quiz' ),
		'parent_item_colon'  => __( 'Parent Questions:', 'pm-social-quiz' ),
		'not_found'          => __( 'No Questions found.', 'pm-social-quiz' ),
		'not_found_in_trash' => __( 'No Questions found in Trash.', 'pm-social-quiz' )
	);

	$args_social_question = array(
		'labels'             => $labels_social_question,
		'public'             => false,
		'publicly_queryable' => false,
		'exclude_from_search' => true,
		'show_ui'            => true,
		'show_in_menu'       => true,
		'query_var'          => false,

		'capability_type'    => 'post',
		'has_archive'        => false,
		'hierarchical'       => false,
		'menu_position'      => null,
		'supports'           => array( 'title', 'author')
	);

	register_post_type( 'social_quiz', $args_social_quiz );
	register_post_type( 'social_question', $args_social_question );
}

/*
	* Display All Post
*/

function pm_social_get_post($entry = null) {
	global $wp_query;
	$args = array(
		'posts_per_page' => -1,
		'post_status' => 'any',
		'post_type' => array('social_question'),
		'orderby' => 'type'
	);
	$query = new WP_Query( $args );
	// The Loop
	while ( $query->have_posts() ) { $query->the_post();
		$selected = ($entry == $query->post->ID ? 'selected' : '');
		print "<option {$selected}  value='{$query->post->ID}'>pid " . $query->post->ID . ': ' . get_the_title( $query->post->ID ) . "</option>";
	}
	// Restore original Post Data
	wp_reset_postdata();
}

/**
 * Display the Question in format
 *
 */

 function pm_social_format_question($postid,$count) {
	$output = '';
	$scrollto = $count;
	$count = $count -1;
	$questions = get_post_meta($postid,'_pm_sqa', true);
	$title = get_the_title($postid);
	$qtype = (get_post_meta($postid,'_pm_sqa_type', true) ? get_post_meta($postid,'_pm_sqa_type', true)  : 'image');
	if(!empty($questions) ):
	$output .= "<li id='social_question_{$count}' class='' >";
		$output .= "<h3><span>{$scrollto}.</span> {$title}</h3>";
		$output .= "<div class='questions_wrapper {$qtype}'>";
		foreach($questions as $key => $q):
		$output .= "<div class='pm_social_question {$qtype}' data-id='social_question_{$scrollto}'>";
		$output .= "<input type='radio' name='pm_social_question[{$count}]' id='pm_social_question[{$count}][{$key}]' value='{$q['score']}' />";
		if($qtype == 'text') {
		$text_value = strip_tags(nl2br($q['text_answer']), '<br><br/>');
		$output .= "<label for='pm_social_question[{$count}][{$key}]'>{$text_value}</label>";
		} else {
		$output .= "<label for='pm_social_question[{$count}][{$key}]'><img src='{$q['answer']}' height='100' /></label>";
		}
		$output .= '<br />';
		$output .= '</div>';
		endforeach;
		$output .= '</div>';
	$output .= '</li>';
	endif;
	return $output;
 }
 

add_filter( 'the_content', 'pm_social_content_quiz', 20 );

/**
 * Add Header Meta Tag
 */

add_action('wp_head','pm_social_meta_tag');

function pm_social_meta_tag() {
	if ( is_single() && is_singular('social_quiz') ):
	global $post;
	$url = get_permalink($post->ID);
	$title = get_the_title($post->ID);
	$desc = nl2br(get_post_meta($post->ID,'_pm_sqa_description', true));
	$image = PM_SOCIAL_QUIZ_DIR.'modules/images/pmsq.jpg';
	$output = '';
	$output .= "<meta property='og:url' content='{$url}'>";
	$output .= "<meta property='og:title' content='{$title}'>";
	$output .= "<meta property='og:description' content='{$desc}'>";
	$output .= "<meta property='og:image' content='{$image}'>";
	endif;
	print $output;
}


/**
 * Share button
 *
 */
 
function pm_social_share_result($pid) {
	$url = get_permalink($pid);
	$urlenc = urlencode($url);
	$title = get_the_title($pid);
	$onlick = "";
	$share_image_fb = "<img src='".PM_SOCIAL_QUIZ_DIR.'modules/images/fbshare.png'."' width='200' />";
	$share_image_tw = "<img src='".PM_SOCIAL_QUIZ_DIR.'modules/images/twittershare.png'."' width='200' />";
	$output = '';
	$output .= "<section class='pm_social_sharing_methods'>";
	$output .= "<p><span>".esc_html(__( 'Share them on Social!' , 'pm-social-quiz' ))."</span><br />";
	$output .= "<a {$onlick} data-href='{$url}' class='share_social fb' href='https://www.facebook.com/sharer/sharer.php?u={$urlenc}'>{$share_image_fb}</a></p>";	
	$output .= "<a {$onlick} class='share_social tw' href='https://twitter.com/home?status={$url}'>{$share_image_tw}</a></p>";
	$output .= "</section>";
	return $output;
}

/**
 * Add Voting at End of Content
 *
 * @uses is_single()
 */
function pm_social_content_quiz( $content ) {

    if ( is_single() && is_singular('social_quiz') ):
		global $post;
		$ranges = get_post_meta($post->ID,'_pm_sqr', true);
		$options = get_option(PM_SOCIAL_QUIZ_SETTINGS_OPTION);
		wp_enqueue_style( 'pm-social-front-style', PM_SOCIAL_QUIZ_DIR.'modules/frontend/css/pm-sq-style.css', '', PM_SOCIAL_QUIZ_VERSION, 'all' );
		wp_enqueue_script('pm-sq-serialize', PM_SOCIAL_QUIZ_DIR.'modules/libs/serialize/jquery.serialize-object.min.js', array('jquery'), PM_SOCIAL_QUIZ_VERSION, true );
		wp_enqueue_script('pm-sq-scrollto', PM_SOCIAL_QUIZ_DIR.'modules/libs/scroll/jquery.scrollTo.min.js', array('jquery'), PM_SOCIAL_QUIZ_VERSION, true );
		wp_enqueue_script('pm-sq-localscroll', PM_SOCIAL_QUIZ_DIR.'modules/libs/scroll/jquery.localScroll.min.js', array('jquery'), PM_SOCIAL_QUIZ_VERSION, true );
		wp_enqueue_script('pm-sq-frontend-script', PM_SOCIAL_QUIZ_DIR.'modules/frontend/js/pm-sq-front.js', array('jquery'), PM_SOCIAL_QUIZ_VERSION, true );
		wp_localize_script( 'pm-sq-frontend-script', 'pmSq', array( 'fbapi' => $options['fbapi'], 'table' => json_encode($ranges), 'finished' => 0));
		
		$count = 1;
		$entries =  get_post_meta($post->ID,'_pm_sq', true);
		if(!empty($entries)): 
		$content .= '<form name="pm_social_questions_form" id="pm_social_questions_form" >';
		$content .= '<ol>';
		foreach($entries as $entry):
			$content .= pm_social_format_question($entry,$count);
			$count ++;
		endforeach; 
		$content .= '</ol>';
		$content .= '<input type="button" id="pm_sq_submit" value="'.esc_html(__( 'Get Results' , 'pm-social-quiz' )).'">';
		$content .= '</form>';
		$content .= '<div id="pm_sq_result_wrapper"><p class="result_type"></p>';
		$content .= pm_social_share_result($post->ID);
		$content .= '</div>';
		endif;
	endif;
    return $content;
}

/* <a onclick="window.open(this.href, 'pmsocialwin','left=20,top=20,width=500,height=200,toolbar=1,resizable=0'); return false;" href="https://www.facebook.com/sharer/sharer.php?u=http%3A%2F%2Fteetalk.ph%2F">Share</a> */